netapp_ontap.models.s3_audit_event_selector API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.s3_audit_event_selector`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class S3AuditEventSelectorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the S3AuditEventSelector object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access: str GET POST PATCH`

    Specifies read and write access types.

    Valid choices:

    - read
    - write
    - all
    - none
  `permission: str GET POST PATCH`

    Specifies allow and deny permission types.

    Valid choices:

    - deny
    - allow
    - all
    - none